translate.convert.tiki2po

Package translate :: Package convert :: Module tiki2po |
[hide private]
[frames] | no frames]

# Module tiki2po

source code

Convert TikiWiki's language.php files to GetText PO files.

Classes | [hide private]
| tiki2po

Functions | [hide private]
converttiki(inputfile, outputfile, template=None, includeunused=False) Converts from tiki file format to po. | source code
main(argv=None) Converts tiki .php files to .po. | source code

Imports: sys, tiki, po

Function Details | [hide private]

### converttiki(inputfile, outputfile, template=None, includeunused=False) | source code
Converts from tiki file format to po. Parameters: `inputfile` - file handle of the source `outputfile` - file handle to write to `template` - unused `includeunused` - Include the "usused" section of the tiki file? Default: False